@@ -3,7 +3,6 @@ import requests
 import cloudlanguagetools.constants
 import cloudlanguagetools.languages
 import secrets
-import pinyin_jyutping_sentence
 
 class MandarinCantoneseTransliteration(cloudlanguagetools.transliterationlanguage.TransliterationLanguage):
     def __init__(self, language, conversion_type, tone_numbers, spaces):
@@ -23,6 +22,16 @@ class MandarinCantoneseTransliteration(cloudlanguagetools.transliterationlanguag
             spaces_str = "Spaces"
         return f'{self.language.lang_name} to {conversion_type_str} ({tone_numbers_str} {spaces_str}), {self.service.name}'
 
+    def get_transliteration_shortname(self):
+        conversion_type_str = self.conversion_type.capitalize()
+        tone_numbers_str = "Diacritics"
+        if self.tone_numbers:
+            tone_numbers_str = "Tone Numbers"
+        spaces_str = ""
+        if self.spaces:
+            spaces_str = "Spaces"
+        return f'{conversion_type_str} ({tone_numbers_str} {spaces_str}), {self.service.name}'        
+
     def get_transliteration_key(self):
         return {
             'conversion_type': self.conversion_type,
@@ -51,6 +60,7 @@ class MandarinCantoneseService(cloudlanguagetools.service.Service):
         return result
 
     def get_transliteration(self, text, transliteration_key):
+        import pinyin_jyutping_sentence
 
         if transliteration_key['conversion_type'] == 'pinyin':
             return pinyin_jyutping_sentence.pinyin(text, tone_numbers=transliteration_key['tone_numbers'], spaces=transliteration_key['spaces'])
